@@ -95,7 +95,8 @@ from __future__ import annotations
 import datetime
 import os
 import re
-from collections.abc import Callable
+from collections.abc import Callable, Sequence
+from enum import Enum, EnumMeta
 from typing import TYPE_CHECKING, Any, Generic, Iterable, TypeVar
 
 import numpy as np
@@ -118,6 +119,65 @@ if TYPE_CHECKING:
 _T = TypeVar("_T")
 
 
+class LabeledEnum(str, Enum):
+    """Enum with invariant key and optional translated label.
+
+    This enum supports Pattern 1:
+    - .value is the invariant key (used for API, serialization, comparisons)
+    - .label is the human-readable string (translated or not) used for UI display
+    - Seamless interoperability: enum_member == string_value works
+
+    Example:
+        class MyEnum(LabeledEnum):
+            OPTION1 = "opt1", _("Option 1")
+            OPTION2 = "opt2", _("Option 2")
+            OPTION3 = "opt3"  # Uses key as label
+
+        # These are equivalent:
+        MyEnum.OPTION1 == "opt1"  # True
+        func(MyEnum.OPTION1) == func("opt1")  # Same behavior
+    """
+
+    def __new__(cls, value, label=None):
+        if label is None:
+            label = value
+        # Initialize the str part with the value for consistent string behavior
+        # This ensures string operations, comparisons, and isinstance(obj, str) work
+        obj = str.__new__(cls, value)
+        obj._value_ = value  # stable key
+        obj.label = label  # UI label (possibly translated)
+        return obj
+
+    def __str__(self) -> str:
+        """Return the label for display purposes."""
+        return str(self.label)
+
+    def __repr__(self) -> str:
+        """Return the string representation of the enum value.
+
+        This is crucial for code generation where enum members are used as default
+        parameter values. By returning the string value directly, we avoid the need
+        for makefun to resolve enum class references in generated function signatures.
+        """
+        return repr(self._value_)
+
+    def __format__(self, format_spec):
+        """Use the label when formatting for display."""
+        return format(str(self.label), format_spec)
+
+    def __eq__(self, other) -> bool:
+        """Enable seamless comparison between enum members and their string values."""
+        if isinstance(other, self.__class__):
+            return self._value_ == other._value_
+        elif isinstance(other, str):
+            return self._value_ == other
+        return False
+
+    def __hash__(self) -> int:
+        """Use the value for hashing to enable set operations with strings."""
+        return hash(self._value_)
+
+
 class NumericTypeItem(DataItem):
     """Numeric data item
 
@@ -134,6 +194,8 @@ class NumericTypeItem(DataItem):
           edit widget (default is False)
         help: text shown in tooltip (optional)
         check: if False, value is not checked (optional, default=True)
+        allow_none: if True, None is a valid value regardless of other constraints
+          (optional, default=False)
     """
 
     type: type[int | float]
@@ -148,8 +210,11 @@ class NumericTypeItem(DataItem):
         unit: str = "",
         help: str = "",
         check: bool = True,
+        allow_none: bool = False,
     ) -> None:
-        super().__init__(label, default=default, help=help, check=check)
+        super().__init__(
+            label, default=default, help=help, check=check, allow_none=allow_none
+        )
         self.set_prop("data", min=min, max=max, nonzero=nonzero, check_value=check)
         self.set_prop("display", unit=unit)
 
@@ -184,19 +249,27 @@ class NumericTypeItem(DataItem):
             text += " " + unit
         return text
 
-    def check_value(self, value: float | int) -> bool:
+    def check_value(self, value: float | int, raise_exception: bool = False) -> bool:
         """Override DataItem method"""
         if not self.get_prop("data", "check_value", True):
             return True
         if not isinstance(value, self.type):
+            if raise_exception:
+                raise TypeError(f"Expected {self.type}, got {type(value)}")
             return False
         if self.get_prop("data", "nonzero") and value == 0:
+            if raise_exception:
+                raise ValueError("Zero is not a valid value")
             return False
         _min = self.get_prop("data", "min")
         if _min is not None and value < _min:
+            if raise_exception:
+                raise ValueError(f"Value {value} is lower than minimum {_min}")
             return False
         _max = self.get_prop("data", "max")
         if _max is not None and value > _max:
+            if raise_exception:
+                raise ValueError(f"Value {value} is greater than maximum {_max}")
             return False
         return True
 
@@ -230,6 +303,8 @@ class FloatItem(NumericTypeItem):
          edit widget (default is False)
         help: text shown in tooltip (optional)
         check: if False, value is not checked (optional, default=True)
+        allow_none: if True, None is a valid value regardless of other constraints
+         (optional, default=False)
     """
 
     type = float
@@ -246,6 +321,7 @@ class FloatItem(NumericTypeItem):
         slider: bool = False,
         help: str = "",
         check: bool = True,
+        allow_none: bool = False,
     ) -> None:
         super().__init__(
             label,
@@ -256,10 +332,28 @@ class FloatItem(NumericTypeItem):
             unit=unit,
             help=help,
             check=check,
+            allow_none=allow_none,
         )
         self.set_prop("display", slider=slider)
         self.set_prop("data", step=step)
 
+    def _set_value_with_validation(
+        self, instance: Any, value: Any, force_allow_none: bool = False
+    ) -> None:
+        """Override DataItem._set_value_with_validation to convert integers to float"""
+        # Try to convert NumPy numeric types to Python float
+        # (will convert silently either floating point or integer types to float)
+        try:
+            if hasattr(value, "dtype") and not isinstance(value, self.type):
+                value = self.type(value)
+        except (TypeError, ValueError):
+            pass
+        # Now acceptable values could be either float or int
+        # (no more NumPy types at this point)
+        if isinstance(value, int):
+            value = float(value)
+        super()._set_value_with_validation(instance, value, force_allow_none)
+
     def get_value_from_reader(
         self, reader: HDF5Reader | JSONReader | INIReader
     ) -> float:
@@ -284,6 +378,8 @@ class IntItem(NumericTypeItem):
          edit widget (default is False)
         help: text shown in tooltip (optional)
         check: if False, value is not checked (optional, default=True)
+        allow_none: if True, None is a valid value regardless of other constraints
+         (optional, default=False)
     """
 
     type = int
@@ -300,6 +396,7 @@ class IntItem(NumericTypeItem):
         slider: bool = False,
         help: str = "",
         check: bool = True,
+        allow_none: bool = False,
     ) -> None:
         super().__init__(
             label,
@@ -310,6 +407,7 @@ class IntItem(NumericTypeItem):
             unit=unit,
             help=help,
             check=check,
+            allow_none=allow_none,
         )
         self.set_prop("data", even=even)
         self.set_prop("display", slider=slider)
@@ -325,17 +423,34 @@ class IntItem(NumericTypeItem):
                 auto_help += ", " + _("odd")
         return auto_help
 
-    def check_value(self, value: Any) -> bool:
+    def _set_value_with_validation(
+        self, instance: Any, value: Any, force_allow_none: bool = False
+    ) -> None:
+        """Override DataItem._set_value_with_validation
+        to convert NumPy numeric types to int"""
+        # Try to convert NumPy integer types to Python int
+        # (will convert silently only integer types to int)
+        try:
+            if isinstance(value, np.integer):
+                value = self.type(value)
+        except (TypeError, ValueError):
+            pass
+        super()._set_value_with_validation(instance, value, force_allow_none)
+
+    def check_value(self, value: int, raise_exception: bool = False) -> bool:
         """Override DataItem method"""
         if not self.get_prop("data", "check_value", True):
             return True
-        valid = super().check_value(value)
+        valid = super().check_value(value, raise_exception=raise_exception)
         if not valid:
             return False
         even = self.get_prop("data", "even")
         if even is not None:
             is_even = value // 2 == value / 2.0
             if (even and not is_even) or (not even and is_even):
+                if raise_exception:
+                    oddity = "even" if even else "odd"
+                    raise ValueError(f"Value {value} is not {oddity}")
                 return False
         return True
 
@@ -357,6 +472,9 @@ class StringItem(DataItem):
         regexp: regular expression for checking value (optional)
         help: text shown in tooltip (optional)
         check: if False, value is not checked (ineffective for strings)
+        allow_none: if True, None is a valid value regardless of other constraints
+         (optional, default=False)
+        readonly: if True, the item is read-only (optional, default=False)
     """
 
     type: Any = str
@@ -371,10 +489,16 @@ class StringItem(DataItem):
         regexp: str | None = None,
         help: str = "",
         check: bool = True,
+        allow_none: bool = False,
+        readonly: bool = False,
     ) -> None:
-        super().__init__(label, default=default, help=help, check=check)
+        super().__init__(
+            label, default=default, help=help, check=check, allow_none=allow_none
+        )
         self.set_prop("data", notempty=notempty, regexp=regexp)
-        self.set_prop("display", wordwrap=wordwrap, password=password)
+        self.set_prop(
+            "display", wordwrap=wordwrap, password=password, readonly=readonly
+        )
 
     def get_auto_help(self, instance: DataSet) -> str:
         """Override DataItem method"""
@@ -384,17 +508,40 @@ class StringItem(DataItem):
             auto_help += ", " + _("not empty")
         regexp = self.get_prop_value("data", instance, "regexp")
         if regexp:
-            auto_help += ", " + _("regexp:") + " " + regexp
+            # Wrap regexp in backticks to prevent Sphinx from interpreting
+            # it as a reference
+            auto_help += ", " + _("regexp:") + f" ``{regexp}``"
         return auto_help
 
-    def check_value(self, value: Any) -> bool:
+    def check_value(self, value: str, raise_exception: bool = False) -> bool:
         """Override DataItem method"""
-        notempty = self.get_prop("data", "notempty")
-        if notempty and not value:
+        if not self.get_prop("data", "check_value", True):
+            return True
+
+        # Convert LabeledEnum members to their string values for validation
+        if isinstance(value, LabeledEnum):
+            value = value.value
+
+        if not isinstance(value, self.type):
+            if raise_exception:
+                raise TypeError(f"Expected {self.type}, got {type(value)}")
             return False
-        regexp = self.get_prop("data", "regexp")
+
+        # Get all data properties at once to reduce property lookups
+        data_props = self._props.get("data", {})
+
+        notempty = data_props.get("notempty")
+        if notempty and not value:
+            if raise_exception:
+                raise ValueError("Empty string is not a valid value")
+            return False
+
+        regexp = data_props.get("regexp")
         if regexp is not None:
-            return bool(re.match(regexp, "" if value is None else value))
+            ok = bool(re.match(regexp, value or ""))
+            if not ok and raise_exception:
+                raise ValueError(f"Value {value} does not match regexp {regexp}")
+            return ok
         return True
 
     def from_string(self, value: str) -> str:
@@ -408,6 +555,15 @@ class StringItem(DataItem):
             return "*" * len(strval)
         return strval
 
+    def _set_value_with_validation(
+        self, instance: Any, value: Any, force_allow_none: bool = False
+    ) -> None:
+        """Override DataItem._set_value_with_validation to handle LabeledEnum members"""
+        # Convert LabeledEnum members to their string values before validation
+        if isinstance(value, LabeledEnum):
+            value = value.value
+        super()._set_value_with_validation(instance, value, force_allow_none)
+
     def get_value_from_reader(self, reader: HDF5Reader | JSONReader | INIReader) -> Any:
         """Reads value from the reader object, inside the try...except
         statement defined in the base item `deserialize` method"""
@@ -423,6 +579,10 @@ class TextItem(StringItem):
         notempty: if True, empty string is not a valid value (optional)
         wordwrap: toggle word wrapping (optional)
         help: text shown in tooltip (optional)
+        allow_none: if True, None is a valid value regardless of other constraints
+         (optional, default=False)
+        readonly: if True, the item is read-only (optional, default=False)
+        regexp: regular expression for value validation (optional)
     """
 
     def __init__(
@@ -432,6 +592,9 @@ class TextItem(StringItem):
         notempty: bool | None = None,
         wordwrap: bool = True,
         help: str = "",
+        allow_none: bool = False,
+        readonly: bool = False,
+        regexp: str | None = None,
     ) -> None:
         super().__init__(
             label,
@@ -439,6 +602,9 @@ class TextItem(StringItem):
             notempty=notempty,
             wordwrap=wordwrap,
             help=help,
+            allow_none=allow_none,
+            readonly=readonly,
+            regexp=regexp,
         )
 
 
@@ -451,6 +617,8 @@ class BoolItem(DataItem):
         default: default value (optional)
         help: text shown in tooltip (optional)
         check: if False, value is not checked (optional, default=True)
+        allow_none: if True, None is a valid value regardless of other constraints
+         (optional, default=False)
     """
 
     type = bool
@@ -462,10 +630,22 @@ class BoolItem(DataItem):
         default: bool | None = None,
         help: str = "",
         check: bool = True,
+        allow_none: bool = False,
     ) -> None:
-        super().__init__(label, default=default, help=help, check=check)
+        super().__init__(
+            label, default=default, help=help, check=check, allow_none=allow_none
+        )
         self.set_prop("display", text=text)
 
+    def get_string_value(self, instance: DataSet) -> str:
+        """Override DataItem method"""
+        value_str = "☑" if self.get_value(instance) else "☐"
+        label = self.get_prop_value("display", self, "label")
+        text = self.get_prop_value("display", instance, "text", "")
+        if label and text:
+            value_str += " " + text
+        return value_str
+
     def get_value_from_reader(
         self, reader: HDF5Reader | JSONReader | INIReader
     ) -> bool:
@@ -483,6 +663,8 @@ class DateItem(DataItem):
         format: date format (as in :py:func:`datetime.date.strftime`)
         help: text displayed on data item's tooltip
         check: check value (default: True)
+        allow_none: if True, None is a valid value regardless of other constraints
+         (optional, default=False)
     """
 
     type = datetime.date
@@ -494,8 +676,11 @@ class DateItem(DataItem):
         format: str | None = None,
         help: str | None = "",
         check: bool | None = True,
+        allow_none: bool = False,
     ) -> None:
-        super().__init__(label, default=default, help=help, check=check)
+        super().__init__(
+            label, default=default, help=help, check=check, allow_none=allow_none
+        )
         self.set_prop("display", format=format)
 
 
@@ -508,6 +693,8 @@ class DateTimeItem(DateItem):
         format: date format (as in :py:func:`datetime.date.strftime`)
         help: text displayed on data item's tooltip
         check: check value (default: True)
+        allow_none: if True, None is a valid value regardless of other constraints
+         (optional, default=False)
     """
 
     type = datetime.datetime
@@ -519,8 +706,9 @@ class DateTimeItem(DateItem):
         format: str | None = None,
         help: str | None = "",
         check: bool | None = True,
+        allow_none: bool = False,
     ) -> None:
-        super().__init__(label, default, format, help, check)
+        super().__init__(label, default, format, help, check, allow_none=allow_none)
 
 
 class ColorItem(StringItem):
@@ -528,21 +716,49 @@ class ColorItem(StringItem):
 
     Args:
         label: item name
-        default: default value (optional). Color can be specified as
-         a string (e.g. "#FF0000" or "red") or as a Qt name (e.g. "red")
+        default: default value (optional)
+        notempty: if True, empty string is not a valid value (optional)
+        regexp: regular expression for checking value (optional)
         help: text shown in tooltip (optional)
-        check: if False, value is not checked (optional, default=True)
+        check: if False, value is not checked (ineffective for strings)
+        allow_none: if True, None is a valid value regardless of other constraints
+         (optional, default=True)
     """
 
-    def check_value(self, value: str) -> bool:
+    def __init__(
+        self,
+        label: str,
+        default: str | None = None,
+        notempty: bool | None = None,
+        regexp: str | None = None,
+        help: str = "",
+        check: bool = True,
+        allow_none: bool = True,
+    ) -> None:
+        super().__init__(
+            label,
+            default=default,
+            notempty=notempty,
+            regexp=regexp,
+            help=help,
+            check=check,
+            allow_none=allow_none,
+        )
+
+    def check_value(self, value: str, raise_exception: bool = False) -> bool:
         """Override DataItem method"""
         if not self.get_prop("data", "check_value", True):
             return True
         if not isinstance(value, self.type):
+            if raise_exception:
+                raise TypeError(f"Expected {self.type}, got {type(value)}")
             return False
         from qtpy import QtGui as QG
 
-        return QG.QColor(value).isValid()
+        ok = QG.QColor(value).isValid()
+        if not ok and raise_exception:
+            raise ValueError(f"Value {value} is not a valid color")
+        return ok
 
     def get_value_from_reader(self, reader: HDF5Reader | JSONReader | INIReader) -> str:
         """Reads value from the reader object, inside the try...except
@@ -564,6 +780,8 @@ class FileSaveItem(StringItem):
         regexp: regular expression for checking value (optional)
         help: text shown in tooltip (optional)
         check: if False, value is not checked (optional, default=True)
+        all_files_first: if True, "All files" is the first item in the list
+         (optional, default=False)
     """
 
     def __init__(
@@ -576,10 +794,18 @@ class FileSaveItem(StringItem):
         regexp: str | None = None,
         help: str = "",
         check: bool = True,
+        allow_none: bool = False,
     ) -> None:
         default = os.path.join(*default) if isinstance(default, list) else default
 
-        super().__init__(label, default=default, regexp=regexp, help=help, check=check)
+        super().__init__(
+            label,
+            default=default,
+            regexp=regexp,
+            help=help,
+            check=check,
+            allow_none=allow_none,
+        )
         if isinstance(formats, str):
             formats = [formats]  # type:ignore
         self.set_prop("data", formats=formats)
@@ -596,13 +822,18 @@ class FileSaveItem(StringItem):
             else _("supported file types:") + " *.%s" % ", *.".join(formats)
         )
 
-    def check_value(self, value: str) -> bool:
+    def check_value(self, value: str, raise_exception: bool = False) -> bool:
         """Override DataItem method"""
         if not self.get_prop("data", "check_value", True):
             return True
         if not isinstance(value, self.type):
+            if raise_exception:
+                raise TypeError(f"Expected {self.type}, got {type(value)}")
             return False
-        return len(value) > 0
+        ok = len(value) > 0
+        if not ok and raise_exception:
+            raise ValueError("Empty string is not a valid value")
+        return ok
 
     def from_string(self, value) -> str:
         """Override DataItem method"""
@@ -635,13 +866,18 @@ class FileOpenItem(FileSaveItem):
         check: if False, value is not checked (optional, default=True)
     """
 
-    def check_value(self, value: str) -> bool:
+    def check_value(self, value: str, raise_exception: bool = False) -> bool:
         """Override DataItem method"""
         if not self.get_prop("data", "check_value", True):
             return True
         if not isinstance(value, self.type):
+            if raise_exception:
+                raise TypeError(f"Expected {self.type}, got {type(value)}")
             return False
-        return os.path.exists(value) and os.path.isfile(value)
+        ok = os.path.exists(value) and os.path.isfile(value)
+        if not ok and raise_exception:
+            raise ValueError(f"File {value} does not exist or is not a file")
+        return ok
 
 
 class FilesOpenItem(FileSaveItem):
@@ -655,6 +891,8 @@ class FilesOpenItem(FileSaveItem):
         regexp: regular expression for checking value (optional)
         help: text shown in tooltip (optional)
         check: if False, value is not checked (optional, default=True)
+        all_files_first: if True, "All files" is the first item in the list
+         (optional, default=False)
     """
 
     type = list
@@ -669,19 +907,24 @@ class FilesOpenItem(FileSaveItem):
         regexp: str | None = None,
         help: str = "",
         check: bool = True,
+        allow_none: bool = False,
     ) -> None:
         if isinstance(default, str):
             default = [default]
-        super().__init__(
+        StringItem.__init__(
+            self,
             label,
-            formats=formats,
             default=default,
-            basedir=basedir,
-            all_files_first=all_files_first,
             regexp=regexp,
             help=help,
             check=check,
+            allow_none=allow_none,
         )
+        if isinstance(formats, str):
+            formats = [formats]  # type:ignore
+        self.set_prop("data", formats=formats)
+        self.set_prop("data", basedir=basedir)
+        self.set_prop("data", all_files_first=all_files_first)
         self.set_prop("display", func=self.paths_basename)
 
     @staticmethod
@@ -693,15 +936,19 @@ class FilesOpenItem(FileSaveItem):
             else os.path.basename(paths)
         )
 
-    def check_value(self, value: str) -> bool:
+    def check_value(self, value: str, raise_exception: bool = False) -> bool:
         """Override DataItem method"""
         if not self.get_prop("data", "check_value", True):
             return True
         if value is None:
+            if raise_exception:
+                raise ValueError("Value cannot be None")
             return False
         allexist = True
         for path in value:
             allexist = allexist and os.path.exists(path) and os.path.isfile(path)
+        if not allexist and raise_exception:
+            raise ValueError(f"Some files do not exist or are not files: {value}")
         return allexist
 
     def from_string(self, value: Any) -> list[str]:  # type:ignore
@@ -716,6 +963,8 @@ class FilesOpenItem(FileSaveItem):
     ) -> None:
         """Serialize this item"""
         value = self.get_value(instance)
+        if value is not None and not isinstance(value, (tuple, list)):
+            value = [value]
         writer.write_sequence([fname.encode("utf-8") for fname in value])
 
     def get_value_from_reader(
@@ -736,13 +985,18 @@ class DirectoryItem(StringItem):
         check: if False, value is not checked (optional, default=True)
     """
 
-    def check_value(self, value: str) -> bool:
+    def check_value(self, value: str, raise_exception: bool = False) -> bool:
         """Override DataItem method"""
         if not self.get_prop("data", "check_value", True):
             return True
         if not isinstance(value, self.type):
+            if raise_exception:
+                raise TypeError(f"Expected {self.type}, got {type(value)}")
             return False
-        return os.path.exists(value) and os.path.isdir(value)
+        ok = os.path.exists(value) and os.path.isdir(value)
+        if not ok and raise_exception:
+            raise ValueError(f"Directory {value} does not exist or is not a directory")
+        return ok
 
 
 class FirstChoice:
@@ -769,6 +1023,8 @@ class ChoiceItem(DataItem, Generic[_T]):
         radio: if True, shows radio buttons instead of a combo box
          (default is False)
         size: size (optional) of the combo box or button widget (for radio buttons)
+        allow_none: if True, None is a valid value regardless of other constraints
+         (optional, default=True)
     """
 
     type = Any
@@ -776,29 +1032,115 @@ class ChoiceItem(DataItem, Generic[_T]):
     def __init__(
         self,
         label: str,
-        choices: Iterable[_T] | Callable[[Any], Iterable[_T]],
-        default: tuple[()] | type[FirstChoice] | int | _T | None = FirstChoice,
+        choices: Iterable[_T] | Callable[[Any], Iterable[_T]] | EnumMeta,
+        default: tuple[()] | type[FirstChoice] | int | _T | Enum | None = FirstChoice,
         help: str = "",
         check: bool = True,
         radio: bool = False,
         size: tuple[int, int] | None = None,
+        allow_none: bool = True,
     ) -> None:
+        self._enum_cls: type[Enum] | None = None
         _choices_data: Any
-        if isinstance(choices, Callable):
+        if isinstance(choices, EnumMeta):
+            self._enum_cls = choices
+            # Build _choices_data as [(m.name, m.label, None)] for each member
+            _choices_data = [
+                (m.name, getattr(m, "label", str(m.value)), None) for m in choices
+            ]
+            # Only coerce if default is a real value
+            if default not in (FirstChoice, None):
+                default = self._enum_coerce_in(default)
+        elif isinstance(choices, Callable):
             _choices_data = ItemProperty(choices)
         else:
             _choices_data = []
             for idx, choice in enumerate(choices):
                 _choices_data.append(self._normalize_choice(idx, choice))
-        if default is FirstChoice and not isinstance(choices, Callable):
+        if (
+            default is FirstChoice
+            and isinstance(_choices_data, Sequence)
+            and isinstance(_choices_data[0], Sequence)
+        ):
             default = _choices_data[0][0]
         elif default is FirstChoice:
             default = None
-        super().__init__(label, default=default, help=help, check=check)
+        super().__init__(
+            label, default=default, help=help, check=check, allow_none=allow_none
+        )
         self.set_prop("data", choices=_choices_data)
         self.set_prop("display", radio=radio)
         self.set_prop("display", size=size)
 
+    def check_value(self, value: str, raise_exception: bool = False) -> bool:
+        """Override DataItem method"""
+        if not self.get_prop("data", "check_value", True):
+            return True
+        choices = self.get_prop("data", "choices", [])
+        if not isinstance(choices, ItemProperty):
+            values = [v for v, _k, _i in choices]
+            if value not in values:
+                if raise_exception:
+                    raise ValueError(
+                        f"Invalid value '{value}' (valid values: {values})"
+                    )
+                return False
+        return True
+
+    def _enum_coerce_in(self, v: object) -> str:
+        """Accept Enum member | name | value | label | index
+        → return string name (the storage key).
+        """
+        if self._enum_cls is None:
+            raise TypeError("No Enum class set in ChoiceItem")
+
+        # Enum member
+        if isinstance(v, self._enum_cls):
+            return v.name
+
+        # name (e.g. "LINEAR")
+        if isinstance(v, str) and v in self._enum_cls.__members__:
+            return v
+
+        # value (stable key) or label (UI string)
+        for m in self._enum_cls:
+            if v == m.value or v == getattr(m, "label", str(m.value)):
+                return m.name
+
+        # index
+        if isinstance(v, int):
+            members = list(self._enum_cls)
+            if 0 <= v < len(members):
+                return members[v].name
+
+        raise ValueError(
+            f"Invalid value '{v}' for {self._enum_cls.__name__} "
+            f"(expected a member, name, value, label, or index)"
+        )
+
+    def __get__(self, instance: DataSet, owner: type | None = None) -> Any:
+        """Override DataItem.__get__ to return Enum member if applicable"""
+        # descriptor for user access → return Enum member if applicable
+        if instance is None:
+            return self
+        raw = super().__get__(instance, owner)  # stored key (string) from DataItem
+        if self._enum_cls is not None and raw is not None:
+            return self._enum_cls[raw]  # Enum member
+        return raw  # legacy: keep as-is
+
+    def get_value(self, instance: DataSet) -> str | None:
+        """Override DataItem.get_value"""
+        # guidata internals should call this; keep it returning the raw key
+        return super().__get__(instance, instance.__class__)  # string (or None)
+
+    def _set_value_with_validation(
+        self, instance: Any, value: Any, force_allow_none: bool = False
+    ) -> None:
+        """Override DataItem._set_value_with_validation to accept Enum members"""
+        if self._enum_cls is not None and value is not None:
+            value = self._enum_coerce_in(value)  # → member.name
+        super()._set_value_with_validation(instance, value, force_allow_none)
+
     def _normalize_choice(
         self, idx: int, choice_tuple: tuple[Any, ...]
     ) -> tuple[int, str, None] | tuple[str, str, None]:
@@ -829,6 +1171,8 @@ class MultipleChoiceItem(ChoiceItem):
         default: default value (optional)
         help: text shown in tooltip (optional)
         check: if False, value is not checked (optional, default=True)
+        allow_none: if True, None is a valid value regardless of other constraints
+         (optional, default=True)
     """
 
     def __init__(
@@ -838,10 +1182,28 @@ class MultipleChoiceItem(ChoiceItem):
         default: tuple[()] = (),
         help: str = "",
         check: bool = True,
+        allow_none: bool = True,
     ) -> None:
-        super().__init__(label, choices, default, help, check=check)
+        super().__init__(
+            label, choices, default, help, check=check, allow_none=allow_none
+        )
         self.set_prop("display", shape=(1, -1))
 
+    def check_value(self, value: str, raise_exception: bool = False) -> bool:
+        """Override DataItem method"""
+        if not self.get_prop("data", "check_value", True):
+            return True
+        if not isinstance(value, tuple):
+            if raise_exception:
+                raise ValueError(f"Invalid value '{value}' (expecting tuple)")
+            return False
+        for val in value:
+            if val not in [v for v, _k, _i in self.get_prop("data", "choices", [])]:
+                if raise_exception:
+                    raise ValueError(f"Invalid value '{value}'")
+                return False
+        return True
+
     def horizontal(self, row_nb: int = 1) -> MultipleChoiceItem:
         """
         Method to arange choice list horizontally on `n` rows
@@ -907,7 +1269,11 @@ class ImageChoiceItem(ChoiceItem):
          a function of one argument (key) returning a QIcon instance
         default: default value (optional)
         help: text shown in tooltip (optional)
-        check: if False, value is not checked (optional, default=True)
+        radio: if True, shows radio buttons instead of a combo box
+         (default is False)
+        size: size (optional) of the combo box or button widget (for radio buttons)
+        allow_none: if True, None is a valid value regardless of other constraints
+         (optional, default=True)
     """
 
     def _normalize_choice(
@@ -935,6 +1301,12 @@ class FloatArrayItem(DataItem):
         minmax: "all" (default), "columns", "rows"
         check: if False, value is not checked (optional, default=True)
         variable_size: if True, allows to add/remove row/columns on all axis
+        allow_none: if True, None is a valid value regardless of other constraints
+         (optional, default=True)
+        check_callback: additional callback to check the value
+         (function of two arguments (value, raise_exception) returning a boolean,
+         where value is the value to check and raise_exception is a boolean
+         indicating whether to raise an exception on invalid value)
     """
 
     type = np.ndarray
@@ -949,10 +1321,27 @@ class FloatArrayItem(DataItem):
         minmax: str = "all",
         check: bool = True,
         variable_size=False,
+        allow_none: bool = True,
+        check_callback: Callable[[np.ndarray, bool], bool] | None = None,
     ) -> None:
-        super().__init__(label, default=default, help=help, check=check)
+        super().__init__(
+            label, default=default, help=help, check=check, allow_none=allow_none
+        )
         self.set_prop("display", format=format, transpose=transpose, minmax=minmax)
         self.set_prop("edit", variable_size=variable_size)
+        self.check_callback = check_callback
+
+    def check_value(self, value: np.ndarray, raise_exception: bool = False) -> bool:
+        """Override DataItem method"""
+        if not self.get_prop("data", "check_value", True):
+            return True
+        if not isinstance(value, self.type):
+            if raise_exception:
+                raise TypeError(f"Expected {self.type}, got {type(value)}")
+            return False
+        if self.check_callback is not None:
+            return self.check_callback(value, raise_exception)
+        return True
 
     def format_string(
         self, instance: DataSet, value: Any, fmt: str, func: Callable
@@ -964,18 +1353,21 @@ class FloatArrayItem(DataItem):
         v: np.ndarray = func(value)
         if v.size == 0:
             return "= []"
-        if larg:
-            text = "= ["
-            for flt in v[:-1]:
-                text += fmt % flt + "; "
-            text += fmt % v[-1] + "]"
-        else:
-            text = "~= " + fmt % v.mean()
-            text += " [" + fmt % v.min()
-            text += " .. " + fmt % v.max()
-            text += "]"
-        text += " %s" % unit
-        return str(text)
+        try:
+            if larg:
+                text = "= ["
+                for flt in v[:-1]:
+                    text += fmt % flt + "; "
+                text += fmt % v[-1] + "]"
+            else:
+                text = "~= " + fmt % v.mean()
+                text += " [" + fmt % v.min()
+                text += " .. " + fmt % v.max()
+                text += "]"
+            text += " %s" % unit
+            return str(text)
+        except (ValueError, TypeError):
+            return "= %s %s" % (str(value), unit)
 
     def serialize(
         self,
@@ -1000,13 +1392,24 @@ class DictItem(DataItem):
         default: default value (optional)
         help: text shown in tooltip (optional)
         check: if False, value is not checked (optional, default=True)
+        allow_none: if True, None is a valid value regardless of other constraints
+         (optional, default=False)
     """
 
     type: type[dict[str, Any]] = dict
 
     # pylint: disable=redefined-builtin,abstract-method
-    def __init__(self, label, default: dict | None = None, help="", check=True):
-        super().__init__(label, default=default, help=help, check=check)
+    def __init__(
+        self,
+        label,
+        default: dict | None = None,
+        help="",
+        check=True,
+        allow_none: bool = False,
+    ):
+        super().__init__(
+            label, default=default, help=help, check=check, allow_none=allow_none
+        )
         self.set_prop("display", callback=self.__dictedit)
         self.set_prop("display", icon="dictedit.png")
 
@@ -1056,6 +1459,8 @@ class ButtonItem(DataItem):
         help: text shown in button's tooltip (optional)
         check: if False, value is not checked (optional, default=True)
         size: size (optional) of the button widget
+        allow_none: if True, None is a valid value regardless of other constraints
+         (optional, default=True)
 
     The value of this item is unspecified but is passed to the callback along
     with the whole dataset. The value is assigned the callback`s return value.
@@ -1070,8 +1475,11 @@ class ButtonItem(DataItem):
         help: str = "",
         check: bool = True,
         size: tuple[int, int] | None = None,
+        allow_none: bool = True,
     ) -> None:
-        super().__init__(label, default=default, help=help, check=check)
+        super().__init__(
+            label, default=default, help=help, check=check, allow_none=allow_none
+        )
         self.set_prop("display", callback=callback)
         self.set_prop("display", icon=icon)
         self.set_prop("display", size=size)
